<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Zurück zur vollständigen grafischen Oberfläche',
	'access_mode_texte' => 'vereinfachtes Interface als Textversion anzeigen',
	'admin_debug' => 'Debug',
	'admin_modifier_article' => 'Artikel bearbeiten',
	'admin_modifier_auteur' => 'Autor bearbeiten',
	'admin_modifier_breve' => 'Meldung bearbeiten',
	'admin_modifier_mot' => 'Schlagwort bearbeiten',
	'admin_modifier_rubrique' => 'Rubrik bearbeiten',
	'admin_recalculer' => 'Seite aus Cache löschen',
	'afficher_calendrier' => 'Kalender anzeigen',
	'afficher_trad' => 'Übersetzungen anzeigen',
	'alerte_maj_impossible' => '<b>Achtung!</b> Ihre SQL Datenbank konnte nicht auf die Version @version@ umgestellt werden. Möglicherweise gibt es ein Problem mit den Zugriffsrechten. Bitte setzen Sie sich mit Ihrem Webspace-Provider in Verbindung.',
	'alerte_modif_info_concourante' => 'Achtung - diese Information wurde auf anderem Weg modifiziert. Der aktuelle Wert lautet:',
	'analyse_xml' => 'XML-Analyse',
	'annuler' => 'Abbrechen',
	'antispam_champ_vide' => 'Bitte lassen Sie dieses Feld leer:',
	'articles_recents' => 'Die neuesten Artikel',
	'attention_champ_mini_nb_caractères' => 'Achtung! Mindestens @nb@ Zeichen',
	'avis_1_erreur_saisie' => 'Ihre Eingabe enthält einen Fehler, bitte überprüfen Sie die Informationen.',
	'avis_archive_incorrect' => 'Die archivierte Datei ist keine SPIP-Datei',
	'avis_archive_invalide' => 'Die archivierte Datei ist keine SPIP-Datei',
	'avis_attention' => 'ACHTUNG!',
	'avis_champ_incorrect_type_objet' => 'Falscher Objektname @name@ für Objekt vom Typ @type@',
	'avis_colonne_inexistante' => 'Die Spalte @col@ existiert nicht',
	'avis_erreur' => 'Fehler: Siehe unten',
	'avis_erreur_connexion' => 'Verbindungsfehler',
	'avis_erreur_cookie' => 'Cookie-Problem',
	'avis_erreur_fonction_contexte' => 'Programmfehler. Diese Funktion darf nicht in diesem Zusammenhang aufgerufen werden.',
	'avis_erreur_mysql' => 'SQL-Fehler',
	'avis_erreur_sauvegarde' => 'Fehler in der Sicherung (@type@ @id_objet@) ! ',
	'avis_erreur_visiteur' => 'Ein Problem beim Zugang zum Redaktionssystem ist aufgetreten.',
	'avis_nb_erreurs_saisie' => 'Ihre Eingabe enthält @nb@ Fehler, bitte überprüfen Sie die Informationen.',

	// B
	'barre_a_accent_grave' => 'Grosses A mit accent grave einfügen',
	'barre_aide' => 'Verwende Sie die typografischen Kürzel, um Ihre Seite zu formatieren.',
	'barre_e_accent_aigu' => 'Grosses E mit accent aigu einfügen',
	'barre_eo' => 'Ein E in das O einfügen',
	'barre_eo_maj' => 'Ein E in ein grosses O einfügen',
	'barre_euro' => 'Symbol € einfügen',
	'barre_gras' => '{{fett}} setzen',
	'barre_guillemets' => 'In „Anführungszeichen“ setzen',
	'barre_guillemets_simples' => 'In ‚Anführungszeichen‘ setzen',
	'barre_intertitre' => 'in {{{Zwischentitel}}} umwandeln',
	'barre_italic' => 'in {kursive} Schrift setzen',
	'barre_lien' => 'in [Hyperlink->http://...] umwandeln',
	'barre_lien_input' => 'Bitte geben Sie die Adresse Ihres Links an. Sie können das Format http://www.meinewebsite.com wählen, oder einfach die Nummer eines Artikels dieser Website angeben.',
	'barre_note' => 'In [[Fussnote]] umwandeln',
	'barre_paragraphe' => 'Neuen Absatz anlegen',
	'barre_quote' => '<quote>Nachricht zitieren</quote>',
	'bouton_changer' => 'Ändern',
	'bouton_chercher' => 'Suchen',
	'bouton_choisir' => 'Auswählen',
	'bouton_deplacer' => 'Verschieben',
	'bouton_download' => 'Runterladen',
	'bouton_enregistrer' => 'Speichern',
	'bouton_radio_desactiver_messagerie_interne' => 'Interne Nachrichten abschalten',
	'bouton_radio_envoi_annonces' => 'Editorische Ankündigungen verschicken',
	'bouton_radio_non_envoi_annonces' => 'Keine Ankündigungen verschicken',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Keine Liste der Neuigkeiten verschicken',
	'bouton_recharger_page' => 'Seite neu laden',
	'bouton_telecharger' => 'Runterladen',
	'bouton_upload' => 'Hochladen',
	'bouton_valider' => 'Bestätigen',

	// C
	'cal_apresmidi' => 'nachmittags',
	'cal_jour_entier' => 'ganztägig',
	'cal_matin' => 'morgens',
	'cal_par_jour' => 'Tageskalender',
	'cal_par_mois' => 'Monatskalender',
	'cal_par_semaine' => 'Wochenkalender',
	'choix_couleur_interface' => 'Farbe',
	'choix_interface' => 'Oberflächenfarbe',
	'colonne' => 'Spalte',
	'confirm_changer_statut' => 'Achtung, Sie werden den Status dieses Elementes ändern. Wollen Sie fortfahren?',
	'correcte' => 'korrekt',

	// D
	'date_aujourdhui' => 'heute',
	'date_avant_jc' => 'v.u.Z.',
	'date_dans' => 'in @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'morgen',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ um @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ von @heure_debut@ bis @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ von @heure_debut@@dtabbr@ bis @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@. @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@. @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@.',
	'date_fmt_nomjour_date' => 'am @nomjour@ @date@',
	'date_fmt_periode' => 'Vom @date_debut@ bis zum @date_fin@',
	'date_fmt_periode_abbr' => 'Vom @dtart@@date_debut@@dtabbr@ bis zum @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Von',
	'date_fmt_periode_to' => 'bis',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'Stunden',
	'date_hier' => 'gestern',
	'date_il_y_a' => 'vor @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Sonntag',
	'date_jour_1_abbr' => 'So.',
	'date_jour_1_initiale' => 'S',
	'date_jour_2' => 'Montag',
	'date_jour_2_abbr' => 'Mo.',
	'date_jour_2_initiale' => 'M',
	'date_jour_3' => 'Dienstag',
	'date_jour_3_abbr' => 'Di.',
	'date_jour_3_initiale' => 'D',
	'date_jour_4' => 'Mittwoch',
	'date_jour_4_abbr' => 'Mi.',
	'date_jour_4_initiale' => 'M',
	'date_jour_5' => 'Donnerstag',
	'date_jour_5_abbr' => 'Do.',
	'date_jour_5_initiale' => 'D',
	'date_jour_6' => 'Freitag',
	'date_jour_6_abbr' => 'Fr.',
	'date_jour_6_initiale' => 'F',
	'date_jour_7' => 'Samstag',
	'date_jour_7_abbr' => 'Sa.',
	'date_jour_7_initiale' => 'S',
	'date_jours' => 'Tagen',
	'date_minutes' => 'Minuten',
	'date_mois' => 'Monaten',
	'date_mois_1' => 'Januar',
	'date_mois_10' => 'Oktober',
	'date_mois_10_abbr' => 'Okt.',
	'date_mois_11' => 'November',
	'date_mois_11_abbr' => 'Nev.',
	'date_mois_12' => 'Dezember',
	'date_mois_12_abbr' => 'Dez.',
	'date_mois_1_abbr' => 'Jan.',
	'date_mois_2' => 'Februar',
	'date_mois_2_abbr' => 'Feb.',
	'date_mois_3' => 'März',
	'date_mois_3_abbr' => 'Mrz.',
	'date_mois_4' => 'April',
	'date_mois_4_abbr' => 'Apr.',
	'date_mois_5' => 'Mai',
	'date_mois_5_abbr' => 'Mai',
	'date_mois_6' => 'Juni',
	'date_mois_6_abbr' => 'Jun.',
	'date_mois_7' => 'Juli',
	'date_mois_7_abbr' => 'Juli',
	'date_mois_8' => 'August',
	'date_mois_8_abbr' => 'Aug.',
	'date_mois_9' => 'September',
	'date_mois_9_abbr' => 'Sept.',
	'date_saison_1' => 'Winter',
	'date_saison_2' => 'Frühling',
	'date_saison_3' => 'Sommer',
	'date_saison_4' => 'unabhängig',
	'date_secondes' => 'Sekunden',
	'date_semaines' => 'Wochen',
	'date_un_mois' => 'Monat',
	'date_une_heure' => 'Stunde',
	'date_une_minute' => 'Minute',
	'date_une_seconde' => 'Sekunde',
	'date_une_semaine' => 'Woche',
	'dirs_commencer' => 'um die Installation wirklich zu starten',
	'dirs_preliminaire' => 'Vorbereitung: <b>Berechtigungen einstellen</b>',
	'dirs_probleme_droits' => 'Problem mit den Berechtigungen',
	'dirs_repertoires_absents' => '<p><b>Folgende Verzeichnisse wurden nicht gefunden:</b></p><ul>@bad_dirs@</ul>
  <p>Das liegt wahrscheinlich an unzutreffender Gross- und Kleinschreibung.
  Überprüfen Sie bitte die genaue Schreibweise der oben stehenden Verzeichnisse,
  sollten Sie Abweichungen feststellen, benennen Sie bitte mit Ihrem FTP-Programm die betreffenden Verzeichnisse um.</p>
  <p>Danach können Sie ',
	'dirs_repertoires_suivants' => '<p><b>In die folgenden Verzeichnisse kann nicht geschrieben werden:</b></p><ul>@bad_dirs@</ul>
<p>Um das Problem zu lösen, verwenden Sie bitte Ihren FTP-Client, um die Zugriffsrechte für diese
Verzeichnisse zu setzen.Die Installationsanleitung erläutert die Details dazu.</p>
<p>Wenn Sie diesen Vorgang abgeschlossen haben, können Sie',
	'double_occurrence' => 'Dublette von @balise@',

	// E
	'en_cours' => 'läuft',
	'envoi_via_le_site' => 'Gesendet über Website ',
	'erreur' => 'Fehler',
	'erreur_balise_non_fermee' => 'Letzter Tag nicht geschlossen:',
	'erreur_technique_ajaxform' => 'Ups. Das Formular wurde aufgrund eines technischen Fehlers nicht abgeschickt. Sie können es erneut versuchen.',
	'erreur_technique_enregistrement_champs' => 'Das Feld @champs@ konnte aufgrund eines technischen Problems nicht gespeichert werden.',
	'erreur_technique_enregistrement_impossible' => 'Technisches Prolem: Speichern nicht möglich.',
	'erreur_texte' => 'Fehler',
	'etape' => 'Schritt',

	// F
	'fichier_introuvable' => 'Datei @fichier@ unauffindbar.',
	'fonction_introuvable' => 'Funktion @fonction@() unauffindbar.',
	'form_auteur_confirmation' => 'Bestätigen Sie Ihre Mailadresse',
	'form_auteur_email_modifie' => 'Ihre Mailadresse wurde geändert.',
	'form_auteur_envoi_mail_confirmation' => 'Eine Mail wurde an @email@ gesendet. Sie müssen auf den in ihr angegebenen Link klicken, um die Korrektheit Ihrer Adresse zu bestätigen.',
	'form_auteur_mail_confirmation' => 'Hallo,

Sie möchten Ihre Mail-Adresse ändern.Um Ihre neue Adresse zu bestätigen,
 brauchen Sie nur diesen Link zu öffnen (wenn Sie darauf verzichten,
wird Ihre Adresse beibehalten):

    @url@
',
	'form_deja_inscrit' => 'Sie sind bereits eingetragen.',
	'form_email_non_valide' => 'Ihre E-Mail-Adresse ist ungültig.',
	'form_forum_access_refuse' => 'Sie haben keinen Zugang mehr zu dieser Website.',
	'form_forum_bonjour' => 'Hallo @nom@,',
	'form_forum_confirmer_email' => 'Bitte öffnen sie folgenden URL zum Bestätigen ihrer Mailadresse: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Diese E-Mail-Adresse ist bereits eingetragen. Sie können also Ihr normals Passwort verwenden.',
	'form_forum_identifiant_mail' => 'Ihre neuen Zugangsdaten wurden Ihnen per Mail zugestellt.',
	'form_forum_identifiants' => 'Persönliche Zugangsdaten',
	'form_forum_indiquer_nom_email' => 'Tragen Sie bitte hier Ihren Namen und Ihre E-Mail-Adresse ein. Die persönlichen Zugangsdaten werden Ihnen dann per E-Mail zugeschickt.',
	'form_forum_login' => 'Login:',
	'form_forum_message_auto' => '(automatisch erzeugte Nachricht)',
	'form_forum_pass' => 'Passwort:',
	'form_forum_probleme_mail' => 'E-Mail Problem: Zugangsdaten können nicht verschickt werden.',
	'form_forum_voici1' => 'Hier sind Ihre Zugangsdaten für die Teilnahme an der Website "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Hier sind Ihre Zugangsdaten um Artikel für die Website "@nom_site_spip@" (@adresse_login@) vorzuschlagen:',
	'form_indiquer_email' => 'Bitte geben Sie Ihre E-Mail-Adresse an.',
	'form_indiquer_nom' => 'Bitte geben Sie Ihren Namen an.',
	'form_indiquer_nom_site' => 'Bitte geben Sie den Namen Ihrer Website an.',
	'form_pet_deja_enregistre' => 'Diese Website wurde bereits erfasst',
	'form_pet_signature_pasprise' => 'Ihre Signatur wird nicht berücksichtigt.',
	'form_prop_confirmer_envoi' => 'Endgültig senden',
	'form_prop_description' => 'Beschreibung/Kommentar',
	'form_prop_enregistre' => 'Ihr Vorschlag wurde gespeichert und wird nach Freigabe durch die Redaktion der Website angezeigt.', # MODIF
	'form_prop_envoyer' => 'Nachricht senden',
	'form_prop_indiquer_email' => 'Bitte geben Sie eine gültige E-Mail Adresse an',
	'form_prop_indiquer_nom_site' => 'Bitte geben Sie den Namen der Website an.',
	'form_prop_indiquer_sujet' => 'Bitte geben Sie ein Thema an',
	'form_prop_message_envoye' => 'Nachricht gesendet',
	'form_prop_non_enregistre' => 'Ihr Vorschlag wurde nicht gespeichert.',
	'form_prop_sujet' => 'Thema',
	'form_prop_url_site' => 'URL der der Website',
	'format_date_attendu' => 'Ein Datum im Format tt/mm/jjjj eingeben. ',
	'format_date_incorrecte' => 'Falsches Datum oder Datumsformat',
	'format_heure_attendu' => 'Uhrzeit im Format hh:mm eingeben.',
	'format_heure_incorrecte' => 'Falsches Zeitformat oder Zeit',
	'forum_non_inscrit' => 'Sie sind nicht eingeschrieben oder Adresse bzw. Passwort waren falsch.',
	'forum_par_auteur' => 'von @auteur@',
	'forum_titre_erreur' => 'Fehler...',

	// I
	'ical_texte_rss_articles' => 'Die «backend» Datei mit den Artikeln der Website finden Sie unter dieser Adresse:',
	'ical_texte_rss_articles2' => 'Sie können auch «backend» Dateien für einzelne Rubriken de Website nutzen:',
	'ical_texte_rss_breves' => 'Es gibt ebenfalls eine Datei für die Meldungen der Website. Wenn Sie die Nummer (ID) einer Rubrik angeben, erhalten Sie auchsschliesslich die Meldungen aus dieser Rubrik.',
	'icone_a_suivre' => 'Aufgaben',
	'icone_admin_site' => 'Konfiguration',
	'icone_agenda' => 'Kalender',
	'icone_aide_ligne' => 'Online-Hilfe',
	'icone_articles' => 'Artikel',
	'icone_auteurs' => 'Autoren',
	'icone_brouteur' => 'Übersicht',
	'icone_configuration_site' => 'Konfiguration',
	'icone_configurer_site' => 'Ihre Website konfigurieren',
	'icone_creer_nouvel_auteur' => 'Neuen Autor anlegen',
	'icone_creer_rubrique' => 'Neue Rubrik anlegen',
	'icone_creer_sous_rubrique' => 'Neue Unterrubrik anlegen',
	'icone_deconnecter' => 'Log-Out',
	'icone_discussions' => 'Diskussionen',
	'icone_doc_rubrique' => 'Dokumente der Rubriken',
	'icone_ecrire_article' => 'Neuen Artikel schreiben',
	'icone_edition_site' => 'Redaktion',
	'icone_gestion_langues' => 'Sprachverwaltung',
	'icone_informations_personnelles' => 'Persönliche Informationen',
	'icone_interface_complet' => 'Expertenmodus',
	'icone_interface_simple' => 'Standardmodus',
	'icone_maintenance_site' => 'Wartung',
	'icone_messagerie_personnelle' => 'Persönliche Nachrichten',
	'icone_repartition_debut' => 'Seit Einrichtung der Website',
	'icone_rubriques' => 'Rubriken',
	'icone_sauver_site' => 'Website sichern',
	'icone_site_entier' => 'Ganze Website',
	'icone_sites_references' => 'Verlinkte Websites',
	'icone_statistiques' => 'Statistiken',
	'icone_suivi_activite' => 'Aktivitäten verfolgen',
	'icone_suivi_actualite' => 'Entwicklung der Website',
	'icone_suivi_pettions' => 'Petitionen verwalten',
	'icone_suivi_revisions' => 'Änderungen des Artikels',
	'icone_supprimer_document' => 'Dokument löschen',
	'icone_supprimer_image' => 'Bild löschen',
	'icone_tous_articles' => 'Alle Ihre Artikel',
	'icone_tous_auteur' => 'Alle Autoren',
	'icone_tous_visiteur' => 'Alle Besucher',
	'icone_visiter_site' => 'Website ansehen',
	'icone_voir_en_ligne' => 'Online ansehen',
	'img_indisponible' => 'Bild nicht vorhanden',
	'impossible' => 'unmöglich',
	'info_a_suivre' => 'AUFGABEN »',
	'info_acces_interdit' => 'Zugang gesperrt',
	'info_acces_refuse' => 'Zugang verweigert',
	'info_action' => 'Aktion: @action@',
	'info_administrer_rubriques' => 'Sie können diese Rubrik und ihre Unterrubriken verwalten',
	'info_adresse_non_indiquee' => 'Sie haben keine Adresse zum Testen agegeben!',
	'info_aide' => 'HILFE:',
	'info_ajouter_mot' => 'Wort hinzufügen',
	'info_annonce' => 'ANKÜNDIGUNG',
	'info_annonces_generales' => 'Allgemeine Ankündigungen:',
	'info_article_propose' => 'Vorgeschlagener Artikel',
	'info_article_publie' => 'Veröffentlichter Artikel',
	'info_article_redaction' => 'Artikel in Bearbeitung',
	'info_article_refuse' => 'Abgelehnter Artikel',
	'info_article_supprime' => 'Gelöschter Artikel',
	'info_articles' => 'Artikel',
	'info_articles_a_valider' => 'Zur Veröffentlichung vorgeschlagenen Artikel',
	'info_articles_nb' => '@nb@ Artikel',
	'info_articles_proposes' => 'Vorgeschlagene Artikel',
	'info_articles_un' => '1 Artikel',
	'info_auteurs_nombre' => 'Autor(en):',
	'info_authentification_ftp' => 'Authentifizierung per FTP.',
	'info_breves_2' => 'Meldungen',
	'info_breves_nb' => '@nb@ Meldungen',
	'info_breves_un' => '1 Meldung',
	'info_connexion_refusee' => 'Die Verbindung wurde verweigert.',
	'info_contact_developpeur' => 'Bitte kontaktieren Sie einen der Entwickler.', # MODIF
	'info_contenance' => 'Diese Website enthält:',
	'info_contribution' => 'Beiträge',
	'info_copyright' => '@spip@ ist freie Software im Sinne der @lien_gpl@.',
	'info_copyright_doc' => 'Weitere Informationen finden Sie unter <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'GNU Public License',
	'info_cours_edition' => 'In Bearbeitung',
	'info_creer_repertoire' => 'Bitte legen Sie eine Datei oder ein Verzeichnis mit diesem Namen an: ',
	'info_creer_repertoire_2' => '(Im Unterverzeichnis <b>@repertoire@</b>)',
	'info_creer_vignette' => 'Miniaturbilder automatisch anlegen',
	'info_creerdansrubrique_non_autorise' => 'Sie sind nicht berechtigt, Inhalte in dieser Rubrik anzulegen.',
	'info_deplier' => 'Öffnen',
	'info_descriptif_nombre' => 'Beschreibung(en):',
	'info_description' => 'Beschreibung:',
	'info_description_2' => 'Beschreibung:',
	'info_dimension' => 'Maße:',
	'info_documents_nb' => '@nb@ Dokumente',
	'info_documents_un' => '1 Dokument',
	'info_ecire_message_prive' => 'Neue private Nachricht schreiben',
	'info_email_invalide' => 'Ungültige E-Mail Adresse.',
	'info_en_cours_validation' => 'Ihre Artikel in Bearbeitung',
	'info_en_ligne' => 'Zur Zeit online:',
	'info_envoyer_message_prive' => 'Private Nachricht an diesen Autor schicken',
	'info_erreur_requete' => 'Abfragefehler: ',
	'info_erreur_squelette2' => 'Keine Vorlage <b>@fichier@</b> vorhanden ...',
	'info_erreur_systeme' => 'Systemfahler (Fehler no. @errsys@)',
	'info_erreur_systeme2' => 'Möglicherweise ist die Festplatte voll oder die Datenbank beschädigt.<br />
<span style="color:red;">Versuchen Sie <a href=\'@script@\'>die Datenbank zu reparieren</a>, oder wenden Sie sich an Ihren Provider.</span>',
	'info_fini' => 'Fertig!',
	'info_format_image' => 'Für diese Dateiformate können Vorschaubilder erstellt werden: @gd_formats@.',
	'info_format_non_defini' => 'Undefiniertes Format',
	'info_grand_ecran' => 'Grosser Bildschirm',
	'info_image_aide' => 'HILFE',
	'info_image_process_titre' => 'Methode zum Anlegen der Miniaturbilder',
	'info_impossible_lire_page' => '<b>Fehler!</b> Die Seite <tt><html>@test_proxy@</html></tt> ist nicht über den Proxy erreichbar',
	'info_installation_systeme_publication' => 'Installation von SPIP ...',
	'info_installer_documents' => 'Sie können alle Dokumente im Verzeichnis @upload@ automatisch installieren.',
	'info_installer_ftp' => 'Als Administrator können Sie Dateien (per FTP) direkt in das Verzeichnis <i>@upload@</i> kopieren und sie hier auswählen.', # MODIF
	'info_installer_images' => 'Sie können Bilder in den Formaten JPEG, GIF und PNG verwenden.',
	'info_installer_images_dossier' => 'Bilder ins Verzeichnis @upload@ kopieren um sie hier auswählen zu können.',
	'info_interface_complete' => 'Expertenmodus',
	'info_interface_simple' => 'Standardmodus',
	'info_joindre_document_article' => 'Diesem Artikel können Sie Dokumente folgendem Typs beifügen: ',
	'info_joindre_document_rubrique' => 'Dieser Rubrik können Sie Dokumente folgendem Typs beifügen:',
	'info_joindre_documents_article' => 'Diesem Artikel können Sie Dokumente folgendem Typs beifügen:',
	'info_l_article' => 'Der Artikel',
	'info_la_breve' => 'Die Meldung',
	'info_la_rubrique' => 'Die Rubrik',
	'info_langue_principale' => 'Hauptsprache der Website',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ Pixel',
	'info_les_auteurs_1' => 'von @les_auteurs@ ',
	'info_logo_format_interdit' => 'Nur die Logos im Format @formats@ sind zugelassen.',
	'info_logo_max_poids' => 'Die Logogrösse darf nicht @maxi@ überschreiten (aktuelle Dateigrösse @actuel@).',
	'info_mail_fournisseur' => 'IhrName@Server.de',
	'info_message_2' => 'NACHRICHT',
	'info_message_supprime' => 'NACHRICHT GELÖSCHT',
	'info_messages_nb' => '@nb@ Nachrichten',
	'info_messages_un' => '1 Nachricht',
	'info_mise_en_ligne' => 'Online seit:',
	'info_modification_parametres_securite' => 'Änderung der Sicherheitseinstellungen',
	'info_mois_courant' => 'Im Lauf des Monats:',
	'info_mot_cle_ajoute' => 'Das folgende Wort wurde hinzugefügt zu',
	'info_multi_herit' => 'Standardsprache',
	'info_multi_langues_soulignees' => 'Die Texte des Interface sind in die <u>unterstrichenen Sprachen</u> ganz oder teilweise übersetzt. Wenn Sie eine von ihnen wählen, werden viele Elemente der Website automatisch übersetzt (Datumsangaben, Formulare usw.). In den nicht unterstrichenen Sprachen werden diese Elemente in der Hauptsprache der Website angezeigt.',
	'info_multilinguisme' => 'Mehrsprachigkeit',
	'info_nom_non_utilisateurs_connectes' => 'Ihr Name wird nicht in der Liste der zur Zeit eingelogten Nutzer angezeigt.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Ihr Name wird in der Liste der angemeldeten Nutzer angezeigt.', # MODIF
	'info_nombre_en_ligne' => 'Zur Zeit online:',
	'info_non_resultat' => 'Keine Fundstellen für “@cherche_mot@”',
	'info_non_utilisation_messagerie' => 'Sie nehmen nicht am Nachrichtensystem der Website teil.',
	'info_nouveau_message' => 'SIE HABEN EINE NEUE NACHRICHT',
	'info_nouveaux_messages' => 'SIE HABEN @total_messages@ NEUE NACHRICHTEN',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Diese Information ist obligatorisch.',
	'info_page_actuelle' => 'Aktuelle Seite',
	'info_pense_bete' => 'MERKZETTEL',
	'info_petit_ecran' => 'Kleiner Bildschirm',
	'info_petition_close' => 'Petition geschlossen',
	'info_pixels' => 'Pixel',
	'info_plusieurs_mots_trouves' => 'Mehrere Schlagworte entsprechen Ihrem Suchkriterium “@cherche_mot@”:',
	'info_portfolio_automatique' => 'automatische Mappe:',
	'info_premier_resultat' => '[@debut_limit@ erste Ergebnisse von @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ erste Ergebnisse von @total@]',
	'info_propose_1' => '[@nom_site_spip@] vorgeschlagen : @titre@',
	'info_propose_2' => 'vorgeschlagener Artikel
---------------',
	'info_propose_3' => 'Der Artikel “@titre@” ist zur Veröffentlichung vorgeschlagen.',
	'info_propose_4' => 'Bitte teilen Sie den anderen Autoren Ihre Meinung zu diesem Artikel mit',
	'info_propose_5' => '(im Forum des Artikels). Sie können ihn unter dieser Adresse lesen:',
	'info_publie_01' => 'Der Artikel „@titre@“ wurde von @connect_nom@ freigegeben.',
	'info_publie_1' => '[@nom_site_spip@] VERÖFFENTLICHT: @titre@',
	'info_publie_2' => 'Artikel veröffentlicht
--------------',
	'info_rechercher' => 'Suchen',
	'info_rechercher_02' => 'Suchen:',
	'info_remplacer_vignette' => 'Ersetzen Sie das Standard-Piktogramm durch ein eigenes Logo:',
	'info_rubriques_nb' => '@nb@ Rubriken',
	'info_rubriques_un' => '1 Rubrik',
	'info_sans_titre_2' => 'ohne Titel',
	'info_selectionner_fichier' => 'Sie können eine Datei aus dem Verzeichnis @upload@ auswählen.',
	'info_selectionner_fichier_2' => 'Wählen Sie eine Datei:',
	'info_sites_nb' => '@nb@ Websites',
	'info_sites_un' => '1 Website',
	'info_supprimer_vignette' => 'Icon löschen',
	'info_symbole_bleu' => 'Das <b>blaue</b> Symbol bedeutet <b>Merkzettel</b>, d.h. eine Nachricht nur zu Ihrer eigenen Verwendung.',
	'info_symbole_jaune' => 'Das <b>gelbe</b> Symbol bedeutet <b>Ankündigung an alle Redakteure</b> (für alle Redakteure sichtbar, Änderung nur durch Administratoren)', # MODIF
	'info_symbole_vert' => 'Das <b>grüne</b> Symbol bezeichnet Nachrichten an <b>andere Benutzer</b> der Website.', # MODIF
	'info_telecharger_nouveau_logo' => 'Neues Logo hochladen:',
	'info_telecharger_ordinateur' => 'Von Ihrem Computer hochladen:',
	'info_tous_resultats_enregistres' => ' [alle Ergebnisse sind erfasst]',
	'info_tout_afficher' => 'Alles zeigen',
	'info_travaux_texte' => 'Diese Website ist noch nicht fertig eingerichtet. Schauen Sie später mal wieder rein ...',
	'info_travaux_titre' => 'Website in Bearbeitung',
	'info_trop_resultat' => 'Zu viele Ergebnisse für “@cherche_mot”. Bitte präzisieren Sie Ihre Suchbegriffe.',
	'info_utilisation_messagerie_interne' => 'Sie verwenden das interne Nachrichtensystem der Website. ',
	'info_valider_lien' => 'Link freigeben',
	'info_verifier_image' => ', bitte prüfen Sie, ob Ihre Bilder fehlerfrei übertagen wurden.',
	'info_vignette_defaut' => 'Standardsymbol',
	'info_vignette_personnalisee' => 'Persönliches Icon',
	'info_visite' => 'Besuch:',
	'info_vos_rendez_vous' => 'Ihre kommenden Termine',
	'infos_vos_pense_bete' => 'Ihre Merkzettel',

	// L
	'label_ajout_id_rapide' => 'schnell hinzufügen',
	'label_poids_fichier' => 'Größe',
	'label_ponctuer' => '@label@:',
	'lien_afficher_icones_seuls' => 'Nur Piktogramme anzeigen',
	'lien_afficher_texte_icones' => 'Piktogramme und Beschriftung anzeigen',
	'lien_afficher_texte_seul' => 'Nur Textmenüs',
	'lien_aller_a_la_derniere_page' => 'Zur letzten Seite gehen',
	'lien_aller_a_la_page_nb' => 'Zu Seite @nb@ gehen',
	'lien_aller_a_la_page_precedente' => 'Zur vorherigen Seite gehen',
	'lien_aller_a_la_page_suivante' => 'Zur nächsten Seite gehen',
	'lien_aller_a_la_premiere_page' => 'Zur ersten Seite gehen',
	'lien_liberer' => 'freigeben',
	'lien_liberer_tous' => 'Alle freigeben',
	'lien_nouvea_pense_bete' => 'NEUER MERKZETTEL',
	'lien_nouveau_message' => 'NEUE NACHRICHT',
	'lien_nouvelle_annonce' => 'NEUE ANKÜNDIGUNG',
	'lien_petitions' => 'PETITION',
	'lien_popularite' => 'Beliebtheit: @popularite@%',
	'lien_racine_site' => 'OBERSTE EBENE DER WEBSITE',
	'lien_reessayer' => 'Wiederholen',
	'lien_repondre_message' => 'Nachricht beantworten',
	'lien_supprimer' => 'Löschen',
	'lien_tout_afficher' => 'Alles zeigen',
	'lien_visite_site' => 'Website anzeigen',
	'lien_visites' => '@visites@ Besuche',
	'lien_voir_auteur' => 'Autor anzeigen',
	'ligne' => 'Zeile',
	'login' => 'Login',
	'login_acces_prive' => 'Login zum Redaktionssystem',
	'login_autre_identifiant' => 'Unter anderem Namen anmelden',
	'login_cookie_accepte' => 'Bitte stellen Sie Ihren Webbrowser so ein, dass er sie akzeptiert (zumindest für diese Website).',
	'login_cookie_oblige' => 'Zu Ihrer Sicherheit muss Ihr Browser Cookies akzeptieren, wenn Sie sich bei der Website anmelden.',
	'login_deconnexion_ok' => 'Abmeldung erfolgreich.',
	'login_erreur_pass' => 'Passwort oder Benutzername falsch.',
	'login_espace_prive' => 'Redaktionssystem',
	'login_identifiant_inconnu' => 'Benutzer «@login@» unbekannt.',
	'login_login' => 'Login:',
	'login_login2' => 'Login-ID oder E-Mail:',
	'login_login_pass_incorrect' => '(Login oder Passwort falsch.)',
	'login_motpasseoublie' => 'Passwort vergessen?',
	'login_non_securise' => 'Achtung, dieses Formular ist nicht abgesichert. Wenn Sie sicher stellen wollen, dass Ihr Passwort nicht im Netzwerk mitgehört werden kann, aktivieren Sie bitte Javascript und',
	'login_nouvelle_tentative' => 'Erneut versuchen',
	'login_par_ici' => 'Sie sind angemeldet... hier...',
	'login_pass2' => 'Passwort:',
	'login_preferez_refuser' => '<b>Wenn Sie keine Cookies verwenden wollen</b>, können Sie eine alternative (weniger sichere) Anmeldung nutzen:',
	'login_recharger' => 'diese Seite neu laden',
	'login_rester_identifie' => 'An mich erinnern',
	'login_retour_public' => 'Zurück zur öffentlichen Website',
	'login_retour_site' => 'Zurück zur öffentlichen Website',
	'login_retoursitepublic' => 'Zurück zur öffentlichen Website',
	'login_sans_cookie' => 'Login ohne Cookie',
	'login_securise' => 'Sicheres Login',
	'login_sinscrire' => 'Anmelden',
	'login_test_navigateur' => 'Test Webbrowser/Verbindung',
	'login_verifiez_navigateur' => '(Überprüfen Sie, dass Ihr Webbrowser Ihr Passwort nicht gespeichert hat ...)',

	// M
	'masquer_colonne' => 'Diese Spalte verbergen',
	'masquer_trad' => 'Übersetzungen ausblenden',
	'message_nouveaux_identifiants_echec' => 'Es können keine neuen Zugangsdaten erzeigt werden.',
	'message_nouveaux_identifiants_echec_envoi' => 'Die neuen Zugangsdaten konnten nicht übermittelt werden.',
	'message_nouveaux_identifiants_ok' => 'Die neuen Zugangsdaten wurden an @email@ übermittelt.',
	'module_fichiers_langues' => 'Sprachdateien',

	// N
	'navigateur_pas_redirige' => 'Wenn Ihr Browser keine automatische Weiterleitung unterstützt, klicken Sie hier.',
	'numero' => 'Nummer',

	// O
	'occurence' => 'Vorkommen',
	'onglet_affacer_base' => 'Datenbank löschen',
	'onglet_auteur' => 'Autor',
	'onglet_contenu_site' => 'Inhalte der Website',
	'onglet_evolution_visite_mod' => 'Entwicklung',
	'onglet_fonctions_avances' => 'Erweiterte Einstellungen',
	'onglet_informations_personnelles' => 'Persönliche Informationen',
	'onglet_interactivite' => 'Interaktivität',
	'onglet_messagerie' => 'Nachrichtensystem',
	'onglet_repartition_rubrique' => 'Verteilung auf Rubriken',
	'onglet_save_restaur_base' => 'Datenbank sichern/wieder herstellen',
	'onglet_vider_cache' => 'Sitecache löschen',

	// P
	'pass_choix_pass' => 'Bitte geben Sie Ihr neues Passwort ein:',
	'pass_erreur' => 'Fehler',
	'pass_erreur_acces_refuse' => '<b>Fehler:</b> Sie haben keinen Zugang mehr zur Website.',
	'pass_erreur_code_inconnu' => '<b>Fehler:</b> Angabe entspricht keinem Benutzer mit Zugang zu dieser Website.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Fehler:</b> Die Adresse <tt>@email_oubli@</tt> ist nicht bekannt.',
	'pass_erreur_non_valide' => '<b>Fehler:</b> Diese E-Mail Adresse <tt>@email_oubli@</tt> ist ungültig!',
	'pass_erreur_probleme_technique' => '<b>Fehler:</b> E-Mail kann aufgrund eines technischen Problems nicht gesendet werden.',
	'pass_espace_prive_bla' => 'Das Redaktionssystem dieser Website ist für Besucher zugänglich, die sich angemeldet haben. Nach erfolgreicher Anmeldung können Sie an Artikeln mitarbeiten, eigene Artikel vorschlagen und an allen Diskussionsforen teilnehmen.', # MODIF
	'pass_forum_bla' => 'Sie möchten in einem Forum für eingetragene Besucher der Website schreiben.', # MODIF
	'pass_indiquez_cidessous' => 'Bitte geben Sie die E-Mail Adresse an, mit der Sie sich ursprünglich eingetragen haben. Sie erhalten dann eine Mail mit allen erforderlichen Schritten um wieder Zugang zu bekommen.',
	'pass_mail_passcookie' => '(Diese Nachricht wurde automatisch erzeugt)

Um sich wieder bei der Website
@nom_site_spip@ (@adresse_site@)
anmelden zu können, rufen Sie bitte diese Adresse in Ihrem Webbrowser auf:

    @sendcookie@

Sie können auf dieser Seite ein neues Passwort eingeben und sich wieder bei der Website einloggen.
', # MODIF
	'pass_mot_oublie' => 'Passwort vergessen',
	'pass_nouveau_enregistre' => 'Ihr neues Passwort wurde gespeichert.',
	'pass_nouveau_pass' => 'Neues Passwort',
	'pass_ok' => 'O.K.',
	'pass_oubli_mot' => 'Passwort vergessen',
	'pass_procedure_changer' => 'Um Ihr Paßwort zu ändern, geben Sie bitte die Mailadresse Ihres Accounts an.',
	'pass_quitter_fenetre' => 'Dieses Fenster verlassen',
	'pass_rappel_login' => 'Erinnerung: Ihr Login ist «@login@».',
	'pass_recevoir_mail' => 'Ein Link zum Zurücksetzen Ihres Passworts wurde an Ihre E-Mail-Adresse geschickt (sofern diese gültig ist).',
	'pass_retour_public' => 'Zurück zum öffentlichen Bereich',
	'pass_rien_a_faire_ici' => 'Hier ist nichts zu tun.',
	'pass_vousinscrire' => 'Bei dieser Website anmelden',
	'precedent' => 'zurück',
	'previsualisation' => 'Vorschau',
	'previsualiser' => 'Vorschau anzeigen',

	// R
	'retour' => 'Zurück',

	// S
	'spip_conforme_dtd' => 'SPIP erkennt dieses Dokument als dem DOCTYPE entsprechend:',
	'squelette' => 'Skelett',
	'squelette_inclus_ligne' => 'eingebettetes Skelett, Zeile',
	'squelette_ligne' => 'Skelett, Zeile',
	'stats_visites_et_popularite' => '@visites@ Besuche; Beliebtheit: @popularite@',
	'suivant' => 'weiter',

	// T
	'taille_go' => '@taille@ Start',
	'taille_go_bi' => '@taille@ GiB',
	'taille_ko' => '@taille@ kB',
	'taille_ko_bi' => '@taille@ kiB',
	'taille_mo' => '@taille@ MB',
	'taille_mo_bi' => '@taille@ MiB',
	'taille_octets' => '@taille@ Byte',
	'taille_octets_bi' => '@taille@ Byte',
	'texte_actualite_site_1' => 'Wenn Sie sich mit der Oberfläche des Redaktionssystems vertraut gemacht haben, können Sie „',
	'texte_actualite_site_2' => 'den Expertenmodus aktivieren,',
	'texte_actualite_site_3' => 'um zusätzliche Funktionen zu nutzen.',
	'texte_creation_automatique_vignette' => 'Diese Website generiert automatisch Vorschaubilder. Wenn Sie Bilder in den Formaten @gd_formats@ mit diesem Formular installieren, werden Vorschaubilder mit den maximalen Diemsionen @taille_preview@ Pixel angelegt.',
	'texte_documents_associes' => 'Die folgenden Dokumente wurden dem Artikel zugeordnet jedoch nicht direkt in ihn eingefügt. Ja nach Gestaltung der öffentlichen Website können Sie alle beigeordneten Dokumente angezeigt werden (oder auch nicht).',
	'texte_erreur_mise_niveau_base' => 'Datenbankfehler beim Einrichten der neuen Version. Das Bild <b>@fichier@</b> wurde nicht übernommen (Artikel @id_article@).
 Bitte notieren Sie diesen Hinweis, starten Sie die Aktualisierung erneut und prüfen Sie, ob die Bilder
 in den Artikeln angezeigt werden.',
	'texte_erreur_visiteur' => 'Sie haben versucht, sich mit einer Identität einzuloggen, die dazu nicht berechtigt.',
	'texte_inc_auth_1' => 'Sie sind angemeldet als <b>@auth_login@</b>, aber diese ID existiert nicht bzw. nicht mehr in der Datenbank.
 Versuchen Sie,',
	'texte_inc_auth_2' => 'sich erneut anzumelden',
	'texte_inc_auth_3' => ', nachdem Sie u.U. Ihren Webbrowser neu gestartet haben.',
	'texte_inc_config' => 'Die hier möglichten Einstellungen beeinflussen das grundsätzliche Verhalten Ihrer Website. Wir raten dringend, sie nur zu ändern, wenn Sie vollständig mit der Funktionsweise von SPIP vertraut sind.<br /><br /><b>Es ist ebenfalls mehr als ratsam, diese Einstellungen nur von Ihrem Haupt-Administrator vornehmen zu lassen.</b>',
	'texte_inc_meta_1' => 'Das System konnte die Datei <code>@fichier@</code> nicht speichern. Bitte prüfen Sie als Administrator ', # MODIF
	'texte_inc_meta_2' => 'die Berechtigungen',
	'texte_inc_meta_3' => 'für das Verzeichnis <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'in Bearbeitung',
	'texte_statut_poubelle' => 'im Mülleimer',
	'texte_statut_propose_evaluation' => 'vorgeschlagen',
	'texte_statut_publie' => 'veröffentlicht',
	'texte_statut_refuse' => 'abgelehnt',
	'titre_ajouter_mot_cle' => 'SCHLAGWORT ZUORDNEN:',
	'titre_cadre_raccourcis' => 'SCHNELLZUGANG:',
	'titre_changer_couleur_interface' => 'Farbe der Oberfläche ändern',
	'titre_image_admin_article' => 'Sie können diesen Artikel verwalten',
	'titre_image_administrateur' => 'Administrator', # MODIF
	'titre_image_aide' => 'Hilfe zu diesem Element',
	'titre_image_auteur_supprime' => 'gelöschter Autor',
	'titre_image_redacteur' => 'Redakteur ohne Systemzugang',
	'titre_image_redacteur_02' => 'Redakteur',
	'titre_image_selecteur' => 'Liste anzeigen',
	'titre_image_visiteur' => 'Besucher',
	'titre_joindre_document' => 'DOKUMENT ANFÜGEN',
	'titre_mots_cles' => 'SCHLAGWORTE',
	'titre_probleme_technique' => 'Achtung! Ein Problem mit dem SQL Server verhindert den Zugang zu diesem Teil der Website. Danke für Ihr Verständnis.',
	'titre_publier_document' => 'DOKUMENT IN DIESER RUBRIK VERÖFFENTLICHEN',
	'titre_signatures_attente' => 'Nicht bestätigte Unterschriften',
	'titre_signatures_confirmees' => 'Bestätigte Unterschriften',
	'titre_statistiques' => 'Statistiken',
	'titre_titre_document' => 'Titel des Dokuments:',
	'todo' => 'demnächst',
	'trad_definir_reference' => 'Wählen Sie "@titre@" als Referenz für Übersetzungen',
	'trad_reference' => '(Referenzartikel)',

	// U
	'upload_limit' => 'Die Datei ist zu groß für den Server; die maximal erlaubte Dateigröße für den <i>Upload</i> ist @max@.',

	// Z
	'zbug_balise_b_aval' => ' : Tag B muss vor der Schleife stehen',
	'zbug_balise_inexistante' => 'Fehler: Der Tag @balise@ wurde nicht richtig für  @from@ deklariert.',
	'zbug_balise_sans_argument' => 'Dem Tag @balise@ fehlt ein Parameter',
	'zbug_boucle' => 'Schleife',
	'zbug_boucle_recursive_undef' => 'Die rekursive Schleife @nom@ ist nicht definiert',
	'zbug_calcul' => 'berechnen',
	'zbug_champ_hors_boucle' => 'Feld @champ@ ausserhalb einer Schleife',
	'zbug_champ_hors_critere' => 'Feld @champ@ ohne Kriterium @critere@',
	'zbug_champ_hors_motif' => 'Feld @champ@ befindet sich ausserhalb eines Kontexts @motif@',
	'zbug_code' => 'Code',
	'zbug_critere_inconnu' => 'Unbekanntes Kriterium @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} für eine Tabelle ohne eindeutigen Schlüssel',
	'zbug_distant_interdit' => 'Extern unzulässig',
	'zbug_doublon_table_sans_cle_primaire' => 'Dublette in einer Tabelle ohne eindeutigen Primärschlüssel',
	'zbug_doublon_table_sans_index' => 'Dublette in Tabelle ohne Index',
	'zbug_erreur_boucle_double' => 'Schleife (BOUCLE) @id@ doppelt vorhanden',
	'zbug_erreur_boucle_fermant' => 'Schleife (BOUCLE) @id@: Schluss-Tag fehlt',
	'zbug_erreur_boucle_syntaxe' => 'Syntax der Schleife @id@ fehlerhaft',
	'zbug_erreur_compilation' => 'Fehler beim Kompilieren',
	'zbug_erreur_execution_page' => 'Fehler beim Ausführen',
	'zbug_erreur_filtre' => 'Der Filter @filtre@ ist nicht definiert.',
	'zbug_erreur_filtre_nbarg_min' => 'Filter @filtre@: es fehlen @nb@ Argument(e)',
	'zbug_erreur_meme_parent' => 'Das Kriterium {meme_parent} funktioniert nur mit den Schleifen (FORUMS) und (RUBRIQUES).',
	'zbug_erreur_squelette' => 'Fehler in Layoutvorlage (Skelett)',
	'zbug_hors_compilation' => 'Außerhalb der Kompilation',
	'zbug_info_erreur_squelette' => 'Irrtum auf der Seite',
	'zbug_inversion_ordre_inexistant' => 'Umkehrung einer inexistenten Sortierung ',
	'zbug_pagination_sans_critere' => '#PAGINATION ohne Kriterium {pagination} oder in rekursiver Schleife',
	'zbug_parametres_inclus_incorrects' => 'INCLUDE-Parameter fehlerhaft: @param@',
	'zbug_profile' => 'Rechenzeit: @time@',
	'zbug_resultat' => 'Ergebnis',
	'zbug_serveur_indefini' => 'SQL-Server nicht definiert',
	'zbug_statistiques' => 'Statistik der SQL Abfragen nach Dauer',
	'zbug_table_inconnue' => 'SQL-Tabelle « @table@ » unbekannt',
	'zxml_connus_attributs' => 'bekannte Attribute',
	'zxml_de' => 'von',
	'zxml_inconnu_attribut' => 'Attribut unbekannt',
	'zxml_inconnu_balise' => 'Tag unbekannt',
	'zxml_inconnu_entite' => 'Entity unbekannt',
	'zxml_inconnu_id' => 'ID unbekannt',
	'zxml_mais_de' => 'aber',
	'zxml_non_conforme' => 'entspricht nicht dem Motiv',
	'zxml_non_fils' => 'ist kein Kind von',
	'zxml_nonvide_balise' => 'kein leerer Tag',
	'zxml_obligatoire_attribut' => 'obligatorisches Attribut fehlt in',
	'zxml_succession_fils_incorrecte' => 'Objektreihenfolge inkorrekt',
	'zxml_survoler' => 'Mouseover zeigt korrekte',
	'zxml_valeur_attribut' => 'Attributwert',
	'zxml_vide_balise' => 'leerer Tag',
	'zxml_vu' => 'bereits gesehen',
];
